#!/usr/bin/python3

import os
import re
import sys
import zipfile
import datetime
import subprocess
import tempfile

from addons import get_original_zip, ADDON_DIRECTORY, PATCH_DIRECTORY

def create_patch(orig_directory, curr_directory):
    dir_name = os.path.basename(orig_directory)
    orig_directory = os.path.realpath(orig_directory)
    curr_directory = os.path.realpath(curr_directory)
    proc = subprocess.Popen(["diff", "-ruN", orig_directory, "."], cwd=curr_directory, stdout=subprocess.PIPE)
    output, err = proc.communicate()
    if err:
        print("Error:", err)
    if output:
        print("Creating Patch for:", dir_name)
        if not os.path.isdir(PATCH_DIRECTORY):
            os.makedirs(PATCH_DIRECTORY)

        with open(os.path.join(PATCH_DIRECTORY, f"{dir_name}.patch"), "wb") as f:
            f.write(output)

if __name__ == "__main__":
    if len(sys.argv) < 1:
        print("Usage:", sys.argv[0], "<addon>")
    else:
        addon = sys.argv[1]
        original_file = get_original_zip(addon)
        if not original_file:
            print("Could not find original zip file. Are you executing this script from the correct path?")
        else:
            zip_file = zipfile.ZipFile(original_file, "r")
            with tempfile.TemporaryDirectory() as temp_dir:
                zip_file.extractall(temp_dir)
                zip_file.close()
                for directory in os.listdir(temp_dir):
                    cur_dir = os.path.join(ADDON_DIRECTORY, directory)
                    orig_directory = os.path.join(temp_dir, directory)
                    if os.path.isdir(orig_directory) and os.path.isdir(cur_dir):
                        create_patch(orig_directory, cur_dir)
